/* 定义颜色变量 - 浅色模式 */
:root {
  --bg-color: #f8f9fa;
  --text-color: #333333;
  --secondary-text: #666666;
  --input-bg: #ffffff;
  --input-border: #cccccc;
  --button-bg: #007bff;
  --button-hover: #0056b3;
  --button-text: #ffffff;
  --button-shadow: hsla(0, 0%, 0%, 0.20);
  --menu-bg: #f0f0f0;
  --menu-text: #333333;
  --menu-width: 170px;
  --menu-selected-bg: #cccccc;
  /* 将进度条颜色变量修改为蓝色 */
  --progress-bar-color: #0d6efd; /* 标准蓝色 */
  --background-bar-color: #e0e0e0; /* 浅色背景下的进度条颜色 */
}

/* 深色模式变量 */
@media (prefers-color-scheme: dark) {
  :root {
    --bg-color: #222222;
    --text-color: #e0e0e0;
    --secondary-text: #aaaaaa;
    --input-bg: #333333;
    --input-border: #555555;
    --button-bg: #0062cc;
    --button-hover: #0069d9;
    --button-text: #f0f0f0;
    --button-shadow: hsla(0, 0%, 0%, 0.40);
    --menu-bg: #333333;
    --menu-text: #e0e0e0;
    --menu-selected-bg: #555555;
    /* 将深色模式下的进度条颜色修改为较亮的蓝色 */
    --progress-bar-color: #315188; /* 较亮的蓝色，适合深色背景 */
    --background-bar-color: #333333; /* 深色背景下的进度条颜色 */
  }
}

.ansi-url{
  color: #4064a0;
  text-decoration: underline;
}

/* ... (其余的 ANSI 颜色、基本样式、表单样式、按钮样式、提示样式、菜单切换按钮、手机端优化、消息和二维码样式保持不变) ... */
.ansi-30m { color: #000000; }
.ansi-31m { color: #bb271b; }
.ansi-32m { color: #61992e; }
.ansi-33m { color: #bea235; }
.ansi-34m { color: #4064a0; }
.ansi-35m { color: #705278; }
.ansi-36m { color: #449598; }
.ansi-37m { color: #d4d7d0; }
.ansi-90m { color: #565752; }
.ansi-91m { color: #dc3f36; }
.ansi-92m { color: #53b739; }
.ansi-93m { color: #f9ea6b; }
.ansi-94m { color: #7c9ecb; }
.ansi-95m { color: #de30c5; }
.ansi-96m { color: #51b2bb; }
.ansi-97m { color: #eeeeec; }

@media (prefers-color-scheme: dark) {
  .ansi-30m { color: #ffffff; }
  .ansi-31m { color: #bb271b; }
  .ansi-32m { color: #61992e; }
  .ansi-33m { color: #bea235; }
  .ansi-34m { color: #4064a0; }
  .ansi-35m { color: #705278; }
  .ansi-36m { color: #449598; }
  .ansi-37m { color: #d4d7d0; }
  .ansi-90m { color: #565752; }
  .ansi-91m { color: #dc3f36; }
  .ansi-92m { color: #53b739; }
  .ansi-93m { color: #f9ea6b; }
  .ansi-94m { color: #7c9ecb; }
  .ansi-95m { color: #de30c5; }
  .ansi-96m { color: #51b2bb; }
  .ansi-97m { color: #eeeeec; }
}

/* 基本样式 */
body {
  font-family: Arial, sans-serif;
  background-color: var(--bg-color);
  color: var(--text-color);
  transition: background-color 0.3s, color 0.3s;
  margin: 0;
  display: flex;
}
nav {
  width: var(--menu-width);
  background-color: var(--menu-bg);
  color: var(--menu-text);
  height: 100vh;
  position: sticky;
  top: 0;
  z-index: 1000;
  transition: width 0.3s, padding 0.3s, color 0.3s;
}
nav.hidden {
  width: 0;
  padding: 0;
  overflow: hidden;
}
nav ul {
  list-style: none;
  padding: 0;
}
nav h3 {
  text-align: center;
  margin: 20px 0 0;
  font-size: 20px;
}
nav li {
  margin: 5px 0;
  cursor: pointer;
  transition: background-color 0.3s, color 0.3s;
  padding: 0 20px;
  height: 40px;
  line-height: 40px;
}
nav li:hover {
  background-color: var(--menu-selected-bg);
  color: var(--button-hover);
}
main {
  flex: 1;
  padding: 40px;
  max-width: 520px;
  transition: margin-left 0.3s;
}
main.full {
  margin-left: 0;
}

/* 表单与消息区域共用样式 */
.common-area {
  width: 100%;
  max-width: 520px;
  color: var(--text-color);
  transition: background-color 0.3s, color 0.3s, border-color 0.3s;
  box-sizing: border-box;
  line-height: 1.1;
  overflow-x: auto; /* 当内容超出宽度时显示水平滚动条（可选） */
  overflow-y: auto;
  word-break: break-word;
  overflow-wrap: break-word;
  white-space: pre-wrap; /* 保留换行并允许自动换行 */
}
textarea {
  height: 250px;
  font-size: 16px;
  border: 1px solid var(--input-border);
  border-radius: 4px;
  background-color: var(--input-bg);
  font-family: 'Courier New', Courier, monospace; /* 添加字体 */
}
#inputOutput {
  padding: 4px 8px;
}
#messageDownload {
  padding: 0 8px;
  max-height: 180px;
  max-width: 99%;
  height: auto;  
  border: 0px;
  border-radius: 4px;
  background-color: var(--bg-color);
}
#messageArea {
  padding: 4px 8px;
  height: 250px;
  font-size: 12px;
  border: 1px solid var(--input-border);
  border-radius: 4px;
  background-color: var(--input-bg);
  font-family: 'Courier New', Courier, monospace; /* 添加字体 */
}
#messageHttp {
  padding: 4px 8px;
  height: 100px;
  font-size: 12px;
  border: 1px solid var(--input-border);
  border-radius: 4px;
  background-color: var(--input-bg);
  font-family: 'Courier New', Courier, monospace; /* 添加字体 */
}
.button-container {
  margin-top: 10px;
  display: flex;
  justify-content: center; /* 水平居中 */
  flex-wrap: wrap; /* 换行 */
  gap: 10px; /* 按钮间距 */
}
button {
  background-color: var(--button-bg);
  color: var(--button-text);
  border: none;
  padding: 12px 18px;
  font-size: 16px;
  border-radius: 6px;
  cursor: pointer;
  transition: background-color 0.3s, box-shadow 0.3s;
  box-shadow: 2px 2px 8px var(--button-shadow);
  margin: 5px;
}
button:hover {
  background-color: var(--button-hover);
}
.hint {
  font-size: 14px;
  color: var(--secondary-text);
  margin-top: 10px;
}
/* 菜单切换按钮 */
#toggleMenu {
  width: 35px;
  height: 40px;
  position: fixed;
  left: var(--menu-width);
  top: 5px;
  background: var(--menu-bg);
  border: none;
  font-size: 20px;
  color: var(--text-color);
  cursor: pointer;
  transition: left 0.3s, color 0.3s;
  border-radius: 0 10px 10px 0;
  display: flex;
  justify-content: center;
  align-items: center;
  box-shadow: 0px 0px 8px var(--button-shadow);
  margin: 0;
}
#toggleMenu:hover {
  color: var(--button-hover);
}

/* 手机端优化 */
@media (max-width: 600px) {
  #messageArea, textarea {
    max-width: none;
  }
  button {
    width: 90%;
  }
  nav {
    position: fixed;
  }
  /* 确保页面宽度不会超出视口 */
  body, html {
    width: 100%;
    overflow-x: hidden;
  }
}
.message {
  padding: 0px;
  margin: 0px;
}

/* 二维码容器样式 */
.qrcode-container {
  display: inline-block; /* 让容器并排显示 */
  margin: 0px;
}

.download-container {
  background-color: var(--input-bg);
  border-radius: 25px;
  border: 4px solid var(--input-bg);
  margin: 4px 0; /* 上下20px间距，左右0 */
}

/* 主进度条样式 */
#mainProgressBar {
  height: 22px;
  font-weight: bold;
  font-size: 16px;
}
.pb-bar {
  max-width: 100%;
  height: 17px;
  background-color: var(--background-bar-color); /* 考虑使用变量 */
  border-radius: 12px;
  overflow: hidden;
  position: relative;
  border: 1px solid var(--input-border);
  font-size: 11px;
}
.pb-progress {
  height: 100%;
  background-color: var(--progress-bar-color);
  width: 0%; /* 根据实际进度更新 */
  transition: width 0.3s ease-in-out;
  border-radius: 12px;
  /* 多背景 */
  background-image:
    linear-gradient(to right, transparent 0%, rgba(255, 255, 255, 0.5) 50%, transparent 100%),
    linear-gradient(to right, rgba(255, 255, 255, 0.15) 0%, rgba(0, 0, 0, 0.15) 100%);
  background-size: 200% 100%, 100% 100%;
  background-repeat: no-repeat, no-repeat;
  /* 初始背景位置 */
  background-position: 100% 0, 0 0; /* 脉冲初始在左侧 */
}
/* 脉冲动画效果 */
.pb-progress.pb-animated {
  /* 动画：名称 时长 缓动函数 延迟 次数 方向 填充模式 播放状态 */
  animation: pb-pulse-lr 4s linear infinite alternate; /* 添加 alternate */
  /* 注意：你也可以调整时长，例如 2s 让单程更快 */
}
/* 关键帧动画 (保持 L-to-R 定义) */
@keyframes pb-pulse-lr {
  0% {
    /* 脉冲背景的右边缘对齐容器右边缘 (高亮在左边缘) */
    background-position: 100% 0, 0 0;
  }
  100% {
    /* 脉冲背景的左边缘对齐容器左边缘 (高亮在右边缘) */
    background-position: 0% 0, 0 0;
  }
}
.pb-status-text {
  position: absolute;
  top: 50%;
  left: 12px; /* 稍微调整左边距 */
  transform: translateY(-50%);
  color: var(--text-color); /* 使用文本颜色变量 */
  z-index: 2; /* 确保状态文本覆盖在进度条上 */
}
.pb-percentage-text {
  position: absolute;
  top: 50%;
  right: 12px; /* 稍微调整右边距 */
  transform: translateY(-50%);
  color: var(--text-color); /* 使用文本颜色变量 */
  z-index: 2; /* 确保百分比文本覆盖在进度条上 */
}

/* 文字滚动样式样式 */
.scroll {
  display: flex;
  width: 100%;
  height: 14px;
  gap: 20px;
}
.scroll-suffix {
  font-size: 7px;
  color: var(--text-color);
  margin-left: auto;
  flex-shrink: 0;
  align-self: flex-end;
  position: relative;
  top: -2px;
}
.scroll-container {
  flex: 1; /* 自适应宽度 */
  max-width: 300px; /* 限制最大宽度 */
  font-size: 14px;
  color: var(--text-color);
  line-height: 14px;
  overflow: hidden;
}
.scroll-content {
  display: inline-flex;
  white-space: nowrap;
}
.scroll-text {
  padding-right: 20px;
}
/* 只有加了scrolling类才动画 */
.scroll-content.scrolling {
  animation: marquee linear infinite;
}
@keyframes marquee {
  0% {
    transform: translateX(0);
  }
  100% {
    transform: translateX(-50%);
  }
}
.speed-text {
  font-size: 14px;
  line-height: 14px;
  padding-left: 12px; /* 向左偏移 10px */
  flex-shrink: 0;
}
.time-text {
  font-size: 14px;
  line-height: 14px;
  padding-right: 12px; /* 向右偏移 10px */
  flex-shrink: 0;
  margin-left: auto;
  align-self: flex-end;
}